==> zio-aws-ec2_2.12-5.20.17.2-sources.jar: zio/aws/ec2/model/SnapshotDetail.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class SnapshotDetail(
    description: Optional[String] = Optional.Absent,
    deviceName: Optional[String] = Optional.Absent,
    diskImageSize: Optional[Double] = Optional.Absent,
    format: Optional[String] = Optional.Absent,
    progress: Optional[String] = Optional.Absent,
    snapshotId: Optional[String] = Optional.Absent,
    status: Optional[String] = Optional.Absent,
    statusMessage: Optional[String] = Optional.Absent,
    url: Optional[String] = Optional.Absent,
    userBucket: Optional[zio.aws.ec2.model.UserBucketDetails] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.SnapshotDetail = {
    import SnapshotDetail.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.SnapshotDetail
      .builder()
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(deviceName.map(value => value: java.lang.String))(
        _.deviceName
      )
      .optionallyWith(diskImageSize.map(value => value: java.lang.Double))(
        _.diskImageSize
      )
      .optionallyWith(format.map(value => value: java.lang.String))(_.format)
      .optionallyWith(progress.map(value => value: java.lang.String))(
        _.progress
      )
      .optionallyWith(snapshotId.map(value => value: java.lang.String))(
        _.snapshotId
      )
      .optionallyWith(status.map(value => value: java.lang.String))(_.status)
      .optionallyWith(statusMessage.map(value => value: java.lang.String))(
        _.statusMessage
      )
      .optionallyWith(url.map(value => value: java.lang.String))(_.url)
      .optionallyWith(userBucket.map(value => value.buildAwsValue()))(
        _.userBucket
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.SnapshotDetail.ReadOnly =
    zio.aws.ec2.model.SnapshotDetail.wrap(buildAwsValue())
}
object SnapshotDetail {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.SnapshotDetail
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.SnapshotDetail =
      zio.aws.ec2.model.SnapshotDetail(
        description.map(value => value),
        deviceName.map(value => value),
        diskImageSize.map(value => value),
        format.map(value => value),
        progress.map(value => value),
        snapshotId.map(value => value),
        status.map(value => value),
        statusMessage.map(value => value),
        url.map(value => value),
        userBucket.map(value => value.asEditable)
      )
    def description: Optional[String]
    def deviceName: Optional[String]
    def diskImageSize: Optional[Double]
    def format: Optional[String]
    def progress: Optional[String]
    def snapshotId: Optional[String]
    def status: Optional[String]
    def statusMessage: Optional[String]
    def url: Optional[String]
    def userBucket: Optional[zio.aws.ec2.model.UserBucketDetails.ReadOnly]
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getDeviceName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("deviceName", deviceName)
    def getDiskImageSize: ZIO[Any, AwsError, Double] =
      AwsError.unwrapOptionField("diskImageSize", diskImageSize)
    def getFormat: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("format", format)
    def getProgress: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("progress", progress)
    def getSnapshotId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("snapshotId", snapshotId)
    def getStatus: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("status", status)
    def getStatusMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("statusMessage", statusMessage)
    def getUrl: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("url", url)
    def getUserBucket
        : ZIO[Any, AwsError, zio.aws.ec2.model.UserBucketDetails.ReadOnly] =
      AwsError.unwrapOptionField("userBucket", userBucket)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.SnapshotDetail
  ) extends zio.aws.ec2.model.SnapshotDetail.ReadOnly {
    override val description: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => value: String)
    override val deviceName: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.deviceName())
      .map(value => value: String)
    override val diskImageSize: Optional[Double] = zio.aws.core.internal
      .optionalFromNullable(impl.diskImageSize())
      .map(value => value: Double)
    override val format: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.format())
      .map(value => value: String)
    override val progress: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.progress())
      .map(value => value: String)
    override val snapshotId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.snapshotId())
      .map(value => value: String)
    override val status: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.status())
      .map(value => value: String)
    override val statusMessage: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.statusMessage())
      .map(value => value: String)
    override val url: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.url())
      .map(value => value: String)
    override val userBucket
        : Optional[zio.aws.ec2.model.UserBucketDetails.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.userBucket())
        .map(value => zio.aws.ec2.model.UserBucketDetails.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.SnapshotDetail
  ): zio.aws.ec2.model.SnapshotDetail.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.12-7.21.15.2-sources.jar: zio/aws/ec2/model/SnapshotDetail.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.SensitiveUrl
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class SnapshotDetail(
    description: Optional[String] = Optional.Absent,
    deviceName: Optional[String] = Optional.Absent,
    diskImageSize: Optional[Double] = Optional.Absent,
    format: Optional[String] = Optional.Absent,
    progress: Optional[String] = Optional.Absent,
    snapshotId: Optional[String] = Optional.Absent,
    status: Optional[String] = Optional.Absent,
    statusMessage: Optional[String] = Optional.Absent,
    url: Optional[SensitiveUrl] = Optional.Absent,
    userBucket: Optional[zio.aws.ec2.model.UserBucketDetails] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.SnapshotDetail = {
    import SnapshotDetail.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.SnapshotDetail
      .builder()
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(deviceName.map(value => value: java.lang.String))(
        _.deviceName
      )
      .optionallyWith(diskImageSize.map(value => value: java.lang.Double))(
        _.diskImageSize
      )
      .optionallyWith(format.map(value => value: java.lang.String))(_.format)
      .optionallyWith(progress.map(value => value: java.lang.String))(
        _.progress
      )
      .optionallyWith(snapshotId.map(value => value: java.lang.String))(
        _.snapshotId
      )
      .optionallyWith(status.map(value => value: java.lang.String))(_.status)
      .optionallyWith(statusMessage.map(value => value: java.lang.String))(
        _.statusMessage
      )
      .optionallyWith(
        url.map(value => SensitiveUrl.unwrap(value): java.lang.String)
      )(_.url)
      .optionallyWith(userBucket.map(value => value.buildAwsValue()))(
        _.userBucket
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.SnapshotDetail.ReadOnly =
    zio.aws.ec2.model.SnapshotDetail.wrap(buildAwsValue())
}
object SnapshotDetail {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.SnapshotDetail
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.SnapshotDetail =
      zio.aws.ec2.model.SnapshotDetail(
        description.map(value => value),
        deviceName.map(value => value),
        diskImageSize.map(value => value),
        format.map(value => value),
        progress.map(value => value),
        snapshotId.map(value => value),
        status.map(value => value),
        statusMessage.map(value => value),
        url.map(value => value),
        userBucket.map(value => value.asEditable)
      )
    def description: Optional[String]
    def deviceName: Optional[String]
    def diskImageSize: Optional[Double]
    def format: Optional[String]
    def progress: Optional[String]
    def snapshotId: Optional[String]
    def status: Optional[String]
    def statusMessage: Optional[String]
    def url: Optional[SensitiveUrl]
    def userBucket: Optional[zio.aws.ec2.model.UserBucketDetails.ReadOnly]
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getDeviceName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("deviceName", deviceName)
    def getDiskImageSize: ZIO[Any, AwsError, Double] =
      AwsError.unwrapOptionField("diskImageSize", diskImageSize)
    def getFormat: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("format", format)
    def getProgress: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("progress", progress)
    def getSnapshotId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("snapshotId", snapshotId)
    def getStatus: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("status", status)
    def getStatusMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("statusMessage", statusMessage)
    def getUrl: ZIO[Any, AwsError, SensitiveUrl] =
      AwsError.unwrapOptionField("url", url)
    def getUserBucket
        : ZIO[Any, AwsError, zio.aws.ec2.model.UserBucketDetails.ReadOnly] =
      AwsError.unwrapOptionField("userBucket", userBucket)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.SnapshotDetail
  ) extends zio.aws.ec2.model.SnapshotDetail.ReadOnly {
    override val description: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => value: String)
    override val deviceName: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.deviceName())
      .map(value => value: String)
    override val diskImageSize: Optional[Double] = zio.aws.core.internal
      .optionalFromNullable(impl.diskImageSize())
      .map(value => value: Double)
    override val format: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.format())
      .map(value => value: String)
    override val progress: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.progress())
      .map(value => value: String)
    override val snapshotId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.snapshotId())
      .map(value => value: String)
    override val status: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.status())
      .map(value => value: String)
    override val statusMessage: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.statusMessage())
      .map(value => value: String)
    override val url: Optional[SensitiveUrl] = zio.aws.core.internal
      .optionalFromNullable(impl.url())
      .map(value => zio.aws.ec2.model.primitives.SensitiveUrl(value))
    override val userBucket
        : Optional[zio.aws.ec2.model.UserBucketDetails.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.userBucket())
        .map(value => zio.aws.ec2.model.UserBucketDetails.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.SnapshotDetail
  ): zio.aws.ec2.model.SnapshotDetail.ReadOnly = new Wrapper(impl)
}
